@@ -2,12 +2,9 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "书签",
-    "Not allowed to access folder to import into" : "不允许访问要导入的文件夹",
-    "Failed to import one bookmark, because: " : "无法导入一个书签，因为：",
     "No file provided for import" : "未提供导入文件",
     "Unsupported file type for import" : "不支持导入的文件类型",
     "A Bookmark manager for Nextcloud" : "适用于 Nextcloud 的书签管理",
-    "This app provides you with a web interface for collecting and organizing bookmarks to the sites on the web that are precious to you. You can browse and filter your bookmarks via tags and folders and by using the built-in search feature. Furthermore, in order to access your bookmarks anywhere, it also allows you to synchronize third-party clients via a built-in REST API -- in your browsers and on your phone.\n\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "此应用为您提供一个Web界面，用于收集和组织对您有价值的网站书签。您可以通过标签和文件夹来浏览和过滤您的书签并使用内置的搜索功能。另外，为使您能从任何地点访问您的书签，它允许您通过内建的REST API与第三方客户端同步——在您的浏览器和您的手机上。\n\n请在这里查看第三方客户端：https://github.com/nextcloud/bookmarks#third-party-clients",
     "Select bookmark" : "选择书签",
     "Details" : "详情",
     "Rename" : "重命名",
@@ -26,7 +23,9 @@ OC.L10N.register(
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["选择了%n个书签"],
     "Enter a link" : "输入一个链接",
     "Create" : "创建",
+    "Cancel" : "取消",
     "Enter folder title" : "输入文件夹标题",
+    "Public" : "公开",
     "Root folder" : "根文件夹",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移动%n个文件夹和一些书签"],
     "_Moving %n folder_::_Moving %n folders_" : ["正在移动%n个文件夹"],
@@ -39,11 +38,11 @@ OC.L10N.register(
     "Export" : "导出",
     "Sorting" : "正在排序",
     "Recently added" : "最近添加",
-    "Alphabetically" : "字母顺序",
+    "Alphabetically" : "按字母顺序",
     "Most visited" : "访问最多",
     "Last modified" : "上一次更改",
-    "RSS Feed" : "RSS ",
-    "This is an RSS feed of the current result set with access restricted to you." : "这是当前结果集的RSS订阅，限制为只有您能访问。",
+    "RSS Feed" : "RSS 订阅源",
+    "This is an RSS feed of the current result set with access restricted to you." : "这是当前 RSS 订阅源的结果集，限制为只有您能访问。",
     "Clear data" : "清除数据",
     "Permanently remove all bookmarks from your account. There is no going back!" : "永久删除您账号中的所有书签。此操作无法恢复！",
     "Delete all bookmarks" : "删除所有书签",
@@ -53,12 +52,20 @@ OC.L10N.register(
     "Also check out the collection of client apps that integrate with this app: " : "还可以查看与此应用集成的客户端应用集合：",
     "Client apps" : "客户端应用",
     "Do you really want to delete all your bookmarks?" : "您确定准备好删除所有的书签吗？",
+    "URL" : "超链接",
     "Creation date" : "创建日期",
     "Tags" : "标签",
     "Select tags are create new ones" : "选择标签或创建新标签",
     "Notes" : "笔记",
     "Sharing" : "正在共享",
     "{time} ago" : "{time} 之前",
+    "Owner" : "拥有者",
+    "Select a user or group" : "选择用户或分组",
+    "Share link" : "共享链接",
+    "Copy link" : "复制链接",
+    "Allow editing" : "允许编辑",
+    "Remove share" : "移除共享",
+    "Link copied" : "已复制链接",
     "Select" : "选择",
     "Previews" : "预览",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "为了显示您书签网站的真实截图，书签应用使用第三方服务生成截图。",
@@ -78,7 +85,7 @@ OC.L10N.register(
     "This URL is already bookmarked! Overwrite?" : "此链接已加入书签！是否覆盖？",
     "Title" : "标题",
     "Link" : "链接",
-    "Enter bookmark url" : "输入书签url",
+    "Enter bookmark URL" : "输入书签网址",
     "Failed to find existing bookmark" : "无法找到已有书签",
     "Failed to create bookmark" : "无法创建书签",
     "Failed to save bookmark" : "无法保存书签",
@@ -92,7 +99,6 @@ OC.L10N.register(
     "Failed to delete parts of selection" : "无法删除部分选择项",
     "Failed to fetch bookmarks." : "无法获取书签",
     "Failed to change setting" : "无法修改设置",
-    "Failed to load setting " : "无法加载设置",
-    "Bookmarks feed" : "书签 Feed"
+    "Bookmarks feed" : "书签订阅源"
 },
 "nplurals=1; plural=0;");
