@@ -76,6 +76,7 @@ class Bookmarks {
 		$this->urlNormalizer = $urlNormalizer;
 		$this->logger = $logger;
 		$this->bookmarksParser = $bookmarksParser;
+		$this->limit = intval($config->getAppValue('bookmarks', 'performance.maxBookmarksperAccount', 0));
 	}
 
 	/**
@@ -306,6 +307,9 @@ class Bookmarks {
 	}
 
 	private function existsFolder($userId, $folderId) {
+		if ($folderId === -1) {
+			return true;
+		}
 		$qb = $this->db->getQueryBuilder();
 		$qb
 			->select('*')
@@ -961,6 +965,18 @@ class Bookmarks {
 
 			return $row['id'];
 		} else {
+			if ($this->limit !== 0) {
+				$qb = $this->db->getQueryBuilder();
+				$qb->select($qb->createFunction('COUNT(*)'))
+				->from('bookmarks', 'b')
+				->where($qb->expr()->eq('user_id', $qb->createPositionalParameter($userid)));
+				$count = $qb->execute()->fetchAll(\PDO::FETCH_COLUMN);
+
+				if (intval($count[0]) > $this->limit) {
+					throw new \InvalidArgumentException('Not allowed to create more than '.$this->limit.' bookmarks');
+				}
+			}
+
 			$qb = $this->db->getQueryBuilder();
 			$qb
 				->insert('bookmarks')
@@ -1048,6 +1064,7 @@ class Bookmarks {
 				]);
 			$qb->execute();
 		}
+		return true;
 	}
 
 	/**
@@ -1163,18 +1180,18 @@ class Bookmarks {
 			return $result;
 		}
 		foreach ($this->bookmarksParser->currentFolder['children'] as $folder) {
-			$rootContent['children'][] = $this->importFolder($userId, $folder, $rootFolder, $result['errors']);
+			$result['children'][] = $this->importFolder($userId, $folder, $rootFolder, $result['errors']);
 		}
 		foreach ($this->bookmarksParser->currentFolder['bookmarks'] as $bookmark) {
 			try {
 				$bmId = $this->addBookmark($userId, $bookmark['href'], $bookmark['title'], $bookmark['tags'], $bookmark['description'], false, [$rootFolder]);
-				$rootContent['children'][] = ['type' => 'bookmark', 'id' => $bmId, 'title' => $bookmark['title'], 'url' => $bookmark['href']];
+				$result['children'][] = ['type' => 'bookmark', 'id' => $bmId, 'title' => $bookmark['title'], 'url' => $bookmark['href']];
 			} catch (\InvalidArgumentException $e) {
 				$this->logger->logException($e, ['app' => 'bookmarks']);
 				$result['errors'][] = $this->l->t('Failed to import one bookmark, because: ') . $e->getMessage();
 			}
 		}
-		return $rootContent;
+		return $result;
 	}
 
 	private function importFolder($userId, $folder, $parentId, &$errors = []) {
